@@ -129,6 +129,18 @@ def update_django_many_to_many(
                 param.add(obj)
 
 
+async def django_sync_to_async_list(
+        django_func,
+        params_to_use=None,
+):
+    if params_to_use is None:
+        params_to_use = {}
+    django_instances_qs = await sync_to_async(django_func)(**params_to_use)
+    django_instances_iter = await sync_to_async(django_instances_qs.__iter__)()
+    django_instances = list(django_instances_iter)
+    return django_instances
+
+
 def django_to_cache(
         django_model,
         redis_model,
@@ -141,7 +153,7 @@ def django_to_cache(
             redis_root,
             get_or_create_redis_model_from_django_model,
     ):
-        django_instances = await sync_to_async(django_model.objects.all)()
+        django_instances = await django_sync_to_async_list(django_model.objects.all)
         async_chunk_size = redis_root.async_db_requests_limit
         async_tasks = []
         completed = 0
@@ -180,7 +192,7 @@ async def update_or_create_redis_instance_from_django_instance(
         get_or_create_redis_model_from_django_model
 ):
     redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
-    redis_dict = django_instance_to_redis_params(
+    redis_dict = await django_instance_to_redis_params(
         django_instance,
         redis_root,
         get_or_create_redis_model_from_django_model
@@ -203,7 +215,7 @@ async def update_or_create_redis_instance_from_django_instance(
     return result_redis_instance
 
 
-def django_instance_field_to_redis_value(
+async def django_instance_field_to_redis_value(
         django_instance,
         django_field,
         redis_root,
@@ -216,20 +228,21 @@ def django_instance_field_to_redis_value(
             redis_value = None
         else:
             django_foreign_key_instance = django_field_value
-            redis_value = get_or_create_redis_instance_from_django_instance(
+            redis_value = await get_or_create_redis_instance_from_django_instance(
                 django_foreign_key_instance,
                 redis_root,
                 get_or_create_redis_model_from_django_model
             )
 
     elif django_field.__class__ == django_models.ManyToManyField:
+        django_many_to_many_instances = await django_sync_to_async_list(django_field_value.all)
         redis_value = [
-            get_or_create_redis_instance_from_django_instance(
+            await get_or_create_redis_instance_from_django_instance(
                 django_many_to_many_instance,
                 redis_root,
                 get_or_create_redis_model_from_django_model
             )
-            for django_many_to_many_instance in django_field_value.all()
+            for django_many_to_many_instance in django_many_to_many_instances
         ]
     elif django_field.__class__.__name__.startswith('Image') or django_field.__class__.__name__.startswith('File'):
         try:
@@ -239,7 +252,7 @@ def django_instance_field_to_redis_value(
     return redis_value
 
 
-def django_instance_to_redis_params(
+async def django_instance_to_redis_params(
         django_instance,
         redis_root,
         get_or_create_redis_model_from_django_model
@@ -247,7 +260,7 @@ def django_instance_to_redis_params(
     redis_params = {}
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
         if not django_field.__class__.__name__.endswith('Rel'):
-            redis_param = django_instance_field_to_redis_value(
+            redis_param = await  django_instance_field_to_redis_value(
                 django_instance,
                 django_field,
                 redis_root,
@@ -257,7 +270,7 @@ def django_instance_to_redis_params(
     return redis_params
 
 
-def get_or_create_redis_instance_from_django_instance(
+async def get_or_create_redis_instance_from_django_instance(
         django_instance,
         redis_root,
         get_or_create_redis_model_from_django_model
@@ -265,9 +278,8 @@ def get_or_create_redis_instance_from_django_instance(
     django_instance_model = django_instance.__class__
     redis_model = get_or_create_redis_model_from_django_model(django_instance_model, redis_root)
     redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
-    print(redis_model, django_instance.id, redis_instance, not redis_instance)
     if not redis_instance:
-        redis_dict = django_instance_to_redis_params(django_instance, redis_root,
+        redis_dict = await django_instance_to_redis_params(django_instance, redis_root,
                                                      get_or_create_redis_model_from_django_model)
         redis_model(
             redis_root=redis_root,
